@@ -2,7 +2,7 @@
 It's my first module, so let me know if I get something wrong about Python
 """
 
-def print_lol(the_list,identation=0,ident=False):
+def print_lol(the_list,identation=0,ident=False,output=sys.stdout):
     """ This function prints all items of a list in the standard output (console)
 	It also prints items of nested items. It does recursively (which is always awesome). """
     for item in the_list:
@@ -13,6 +13,6 @@ def print_lol(the_list,identation=0,ident=False):
             if (ident):                
                 for n in range(identation):
                     iden += "\t"
-            print(iden + str(item))
+            print >> output,(iden + str(item))
             
 
